#
# spec file for package python-pybind11
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pybind11
Version:        2.4.3
Release:        bp153.1.25
Summary:        Module for operability between C++11 and Python
License:        BSD-3-Clause
URL:            https://github.com/pybind/pybind11
Source:         https://github.com/pybind/pybind11/archive/v%{version}.tar.gz#/pybind11-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
pybind11 is a header-only library that exposes C++ types in Python
and vice versa, mainly to create Python bindings of existing C++
code. It can reduce boilerplate code in traditional extension modules
by inferring type information using compile-time introspection.

%package -n %{name}-common-devel
Summary:        Development files for pybind11
Provides:       %{python_module pybind11-common-devel = %{version}}

%description -n %{name}-common-devel
This package contains files for developing applications using pybind11.

%package devel
Summary:        Development files for pybind11
Requires:       %{name}-common-devel = %{version}
Requires:       python-devel
Requires:       python-pybind11 = %{version}

%description devel
This package contains files for developing applications using pybind11.

%prep
%setup -q -n pybind11-%{version}

%build
%python_build
# calling cmake to install header to right location and
# generate cmake include files
%cmake
%cmake_build

%install
%python_install
%cmake_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# removing duplicated header files
rm -rfv %{buildroot}%{_includedir}/python2.*/pybind11/
rm -rfv %{buildroot}%{_includedir}/python3.*/pybind11

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%files -n %{name}-common-devel
%{_includedir}/pybind11
%license LICENSE
%{_datadir}/cmake/pybind11

%files %{python_files devel}
%license LICENSE

%changelog
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- On devel files you need the pybind too to compile anything
* Wed Mar 11 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Feb 13 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix mixup of expanded/unexpaned python versions in devel package,
  the devel package always required python(2)-devel and
  python2-pybind. Move the data to a -common-devel subpackage,
  pulled in by versioned python{2,3}-pybind-devel packages.
* Tue Jan 14 2020 John Vandenberg <jayvdb@gmail.com>
- Add package version to extra devel packages added via Provides
* Sat Dec 21 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4.3
  * Adapt pybind11 to a C API convention change in Python 3.8.
* Tue Oct  8 2019 Christian Goll <cgoll@suse.com>
- updated to 2.4.2
  * made devel package python version independent
  * added cmake run to install cmake include files
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Replace description by something more substantial.
* Mon Jul 22 2019 Michal Vyskocil <mvyskocil@opensuse.org>
- Initial packaging of pybind11 2.3.0 for openSUSE
